prompt --application/set_environment
set define off verify off feedback off
whenever sqlerror exit sql.sqlcode rollback
--------------------------------------------------------------------------------
--
-- ORACLE Application Express (APEX) export file
--
-- You should run the script connected to SQL*Plus as the Oracle user
-- APEX_050100 or as the owner (parsing schema) of the application.
--
-- NOTE: Calls to apex_application_install override the defaults below.
--
--------------------------------------------------------------------------------
begin
wwv_flow_api.import_begin (
 p_version_yyyy_mm_dd=>'2016.08.24'
,p_release=>'5.1.4.00.08'
,p_default_workspace_id=>1680777737499838
,p_default_application_id=>1101
,p_default_owner=>'APEXCONNECT'
);
end;
/
prompt --application/shared_components/plugins/dynamic_action/com_pretius_apex_contextmenu
begin
wwv_flow_api.create_plugin(
 p_id=>wwv_flow_api.id(80558907627836188)
,p_plugin_type=>'DYNAMIC ACTION'
,p_name=>'COM.PRETIUS.APEX.CONTEXTMENU'
,p_display_name=>'Pretius APEX Context Menu'
,p_category=>'NAVIGATION'
,p_supported_ui_types=>'DESKTOP'
,p_javascript_file_urls=>wwv_flow_string.join(wwv_flow_t_varchar2(
'#PLUGIN_FILES#pretius.apexListMenu.js',
''))
,p_css_file_urls=>'#PLUGIN_FILES#pretius.apexListMenu.css'
,p_api_version=>2
,p_render_function=>'#OWNER#.PRETIUS_APEX_CONTEXT_MENU.render'
,p_standard_attributes=>'ITEM:BUTTON:REGION:JQUERY_SELECTOR:JAVASCRIPT_EXPRESSION:TRIGGERING_ELEMENT:EVENT_SOURCE'
,p_substitute_attributes=>true
,p_subscribe_plugin_settings=>true
,p_help_text=>wwv_flow_string.join(wwv_flow_t_varchar2(
'<strong>About plugin</strong>',
'<p>',
'  Pretius APEX Context Menu is dynamic action plugin implementing context menu based on defined APEX list.',
'</p>',
'<p>',
'  Github: <code>https://github.com/bostrowski/Pretius-APEX-Context-Menu</code>',
'</p>',
'<strong>About author</strong>',
'</p>',
'<p>',
'  Author: <code>Bartosz Ostrowski</code><br/>',
'  E-mail: <code>ostrowski.bartosz@gmail.com</code><br/>',
'  Twitter: <code>@bostrowsk1</code><br/>',
'  Website: http://www.ostrowskibartosz.pl',
'</p>',
'<strong>About Pretius</strong>',
'<p>',
'  Website: http://pretius.com',
'</p>'))
,p_version_identifier=>'1.0.0'
,p_about_url=>'https://github.com/bostrowski/Pretius-APEX-Context-Menu'
,p_files_version=>110
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(80559214240848273)
,p_plugin_id=>wwv_flow_api.id(80558907627836188)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>1
,p_display_sequence=>10
,p_prompt=>'List name'
,p_attribute_type=>'TEXT'
,p_is_required=>true
,p_is_translatable=>false
,p_examples=>wwv_flow_string.join(wwv_flow_t_varchar2(
'<h4>Dynamic SQL query</h4>',
'<pre>',
'select ',
'  null                  level,                 --not used',
'  ''Entry text''          label,                 --entry text displayed ',
'  ''javascript: void(0)'' target,                --href attribute value',
'  null                  is_current_list_entry, --not used',
'  ''fa-search''           image,                 --icon to be displayed',
'  null                  image_attribute,       --not used',
'  null                  image_alt_attribute,   --not used',
'  ''ENTRY_ID''            attribute1,            --used to identify entry',
'  ''true''                attribute2,            --disable flag. When "true", entry is disabled',
'  ''false''               attribute3,            --hidden flag. When "true", entry is not rendered',
'  null                  attribute4,            --title - not working',
'  null                  attribute5,            --shortcut - not working',
'  ''Accelerator''         attribute6,            --accelerator text to be displayed next to entry text',
'  null                  attribute7,            --entry type. When "seperator", entry is rendered as separator',
'  null                  attribute8,            --not used',
'  null                  attribute9,            --not used',
'  null                  attribute10            --not used',
'from ',
'  dual',
'</pre>',
'',
'<h4>Dynamic Function returing SQL query</h4>',
'<pre>',
'return ''',
'  select ',
'    null                    level,                 --not used',
'    ''''Entry text''''          label,                 --entry text displayed ',
'    ''''javascript: void(0)'''' target,                --href attribute value',
'    null                    is_current_list_entry, --not used',
'    ''''fa-search''''           image,                 --icon to be displayed',
'    null                    image_attribute,       --not used',
'    null                    image_alt_attribute,   --not used',
'    ''''ENTRY_ID''''            attribute1,            --used to identify entry',
'    ''''true''''                attribute2,            --disable flag. When "true", entry is disabled',
'    ''''false''''               attribute3,            --hidden flag. When "true", entry is not rendered',
'    null                    attribute4,            --title - not working',
'    null                    attribute5,            --shortcut - not working',
'    ''''Accelerator''''         attribute6,            --accelerator text to be displayed next to entry text',
'    null                    attribute7,            --entry type. When "seperator", entry is rendered as separator',
'    null                    attribute8,            --not used',
'    null                    attribute9,            --not used',
'    null                    attribute10            --not used',
'  from ',
'    dual',
''';  ',
'</pre>'))
,p_help_text=>wwv_flow_string.join(wwv_flow_t_varchar2(
'<p>',
'  Oracle APEX <strong>list name</strong> defined in <i>Shared Components > Lists</i>. ',
'  Given list will be rendered as APEX list menu using native APEX menu API.',
'  The plugin support all types of list:',
'</p>',
'<ul>',
'  <li>static</li>',
'  <li>SQL query</li>',
'  <li>function returining SQL query</li>',
'</ul>',
'<br>',
'<p>',
'  List entries are rendered depending on result of authorization scheme. When no authorization scheme is set or authorization scheme passes list entry is rendered.',
'</p>',
'<h4>User Defined Attributes</h4>',
'<p>',
'  User defined attributes can be defined in <i>Shared Components > Lists > List entry</i>.',
'</p>',
'<dl>',
'  <dt>Attribute 1</dt>',
'  <dd>',
'    Provided text is used as <strong>id</strong> for list entry. ',
'    Value can be used to identify list entry when extending with JSON object described in <strong>Override Behaviour</strong> attribute.',
'  </dd>',
'',
'  <dt>Attribute 2</dt>',
'  <dd>',
'    When set to <strong>true</strong> then list entry is disabled.',
'  </dd>',
'',
'  <dt>Attribute 3</dt>',
'  <dd>',
'    When set to <strong>true</strong> then list entry is not rendered',
'  </dd>',
'',
'  <dt>Attribute 4</dt>',
'  <dd>',
'    Reserved by APEX navigation template to set title. Not working.',
'  </dd>',
'',
'  <dt>Attribute 5</dt>',
'  <dd>',
'    Reserved by APEX navigation template to set shortcut(?). Not working.',
'  </dd>',
'',
'  <dt>Attribute 6</dt>',
'  <dd>Provided text is used as <strong>accelerator text</strong> displayed right to entry label.</dd>',
'',
'  <dt>Attribute 7</dt>',
'  <dd>When set to <strong>separator</strong> then display as horizontal separator</dd>',
'',
'  <dt>Attribute 8</dt>',
'  <dd>Not used.</dd>',
'',
'  <dt>Attribute 9</dt>',
'  <dd>Not used.</dd>',
'',
'  <dt>Attribute 10</dt>',
'  <dd>Not used.</dd>',
'',
'</dl>'))
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(36675862707260031)
,p_plugin_id=>wwv_flow_api.id(80558907627836188)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>2
,p_display_sequence=>20
,p_prompt=>'Settings'
,p_attribute_type=>'CHECKBOXES'
,p_is_required=>false
,p_is_translatable=>false
,p_lov_type=>'STATIC'
,p_help_text=>wwv_flow_string.join(wwv_flow_t_varchar2(
'<p>',
'  This attribute allows to do advanced configuration of the plugin. ',
'  Attributes <strong>Override Behaviour</strong> and <strong>Add Extra Entries</strong> requires JavaScript knowledge.',
'</p>'))
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(36678443739264802)
,p_plugin_attribute_id=>wwv_flow_api.id(36675862707260031)
,p_display_sequence=>10
,p_display_value=>'Override Behaviour'
,p_return_value=>'OMB'
,p_help_text=>wwv_flow_string.join(wwv_flow_t_varchar2(
'<p>',
'  When checked, attribute <strong>Override Behaviour</strong> is aviable to set. ',
'  Use this option to add submenu to existing List Entry, override action of List Entry,',
'  set function controlling disability of List Entry.',
'</p>'))
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(36690998808745215)
,p_plugin_attribute_id=>wwv_flow_api.id(36675862707260031)
,p_display_sequence=>20
,p_display_value=>'Add Extra Entries'
,p_return_value=>'EE'
,p_help_text=>wwv_flow_string.join(wwv_flow_t_varchar2(
'<p>',
'  When checked, attribute <strong>Add Extra Entries</strong> is aviable to set. ',
'  Use this option to add entries to existing List. ',
'</p>'))
);
wwv_flow_api.create_plugin_attr_value(
 p_id=>wwv_flow_api.id(36693559509031537)
,p_plugin_attribute_id=>wwv_flow_api.id(36675862707260031)
,p_display_sequence=>30
,p_display_value=>'Fixed Position'
,p_return_value=>'FP'
,p_help_text=>wwv_flow_string.join(wwv_flow_t_varchar2(
'<p>',
'  When checked, menu is positioned using <strong>fixed</strong> position and its position is not affected by scrolling.',
'  This option is helpful when menu is attached to button in breadcrumbs region.',
'</p>'))
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(36682659484473882)
,p_plugin_id=>wwv_flow_api.id(80558907627836188)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>3
,p_display_sequence=>30
,p_prompt=>'Override Behaviour'
,p_attribute_type=>'JAVASCRIPT'
,p_is_required=>true
,p_default_value=>wwv_flow_string.join(wwv_flow_t_varchar2(
'//please read apex inline help text',
'return {};'))
,p_is_translatable=>false
,p_depending_on_attribute_id=>wwv_flow_api.id(36675862707260031)
,p_depending_on_has_to_exist=>true
,p_depending_on_condition_type=>'IN_LIST'
,p_depending_on_expression=>'OMB'
,p_examples=>wwv_flow_string.join(wwv_flow_t_varchar2(
'<p>',
'  Examples describes defined list entry in ',
'  <i>Shared Components > Lists > List entry</i>',
'  with <strong>User Defined Attribute 1</strong>',
'  set to <strong>ENTRY_ATTR01_VALUE</strong>.',
'</p>',
'<strong>Overriding existing list entry bahaviour</strong>',
'<pre><code>return {',
'  "ENTRY_ATTR01_VALUE": {',
'    "action": function( pMenuOptions, pTriggeringElement ){',
'      //Code to be executed when users clicks on entry',
'      return void(0);',
'    },',
'    "disabled": function( pMenuOptions, pEntry ) {',
'      //Code to be executed to determine whether entry is disabled or enabled',
'      //return true to disable list entry',
'      return true;',
'    },',
'    "hide": function( pMenuOptions ){',
'      //Code to be executed to determine whether entry is rendered',
'      //return true to hide list entry',
'      return false;',
'    }',
'  }',
'};</code></pre>',
'',
'<strong>Adding submenu to existing list entry</strong>',
'<pre><code>return {',
'  "ENTRY_ATTR01_VALUE": {',
'    "items": [',
'      {',
'        "type": "subMenu", ',
'        "labelKey": "Label Text",',
'        "icon": "fa-pencil",',
'        "accelerator" : "",',
'        "href": "",',
'        "action": function(pMenuOptions, pTriggeringElement) {',
'          return void(0);',
'        },',
'        "disabled": function( pMenuOptions, pEntry ) {',
'          return false;',
'        },',
'        "hide": function( pMenuOptions ){',
'          return false;',
'        },',
'        //optional submenu of "Label Text" entry',
'        "items": [',
'          //Array of objests describing list Entries',
'          ...',
'        ]',
'      },',
'      ...',
'    ]',
'  }',
'};</code></pre>'))
,p_help_text=>wwv_flow_string.join(wwv_flow_t_varchar2(
'<p>',
'  This attribute can be used to <strong>extend existing list entry</strong>:',
'  <ul>',
'    <li>add submenu</li>',
'    <li>override action</li>',
'    <li>set disable property</li>',
'    <li>hide</li>',
'  </ul>',
'</p>',
'<p>',
'  Entry to be extended must has set <strong>User Defined Attribute 1</strong> to unique text - entry id.',
'</p>',
'<p>',
'  To learn about entry properties please refer oracle apex menu API ',
'  https://docs.oracle.com/database/apex-18.1/AEXJS/menu.html',
'</p>',
'<p>',
'  Supported properties are:',
'</p>',
'<ul>',
'  <li>type</li>',
'  <li>id</li>',
'  <li>label</li>',
'  <li>labelKey</li>',
'  <li>hide</li>',
'  <li>disabled</li>',
'  <li>icon</li>',
'  <li>iconStyle</li>',
'  <li>href</li>',
'  <li>action</li>',
'  <li>accelerator</li>',
'  <li>menu*</li>',
'</ul>',
'<p>',
'<code>* menu </code> property is implemented via property items to avoid unnecessary nested objects. See examples below.',
'</p>'))
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(36688282702731991)
,p_plugin_id=>wwv_flow_api.id(80558907627836188)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>4
,p_display_sequence=>40
,p_prompt=>'Extra entries'
,p_attribute_type=>'JAVASCRIPT'
,p_is_required=>true
,p_default_value=>wwv_flow_string.join(wwv_flow_t_varchar2(
'//please read apex inline help text',
'return [];'))
,p_is_translatable=>false
,p_depending_on_attribute_id=>wwv_flow_api.id(36675862707260031)
,p_depending_on_has_to_exist=>true
,p_depending_on_condition_type=>'IN_LIST'
,p_depending_on_expression=>'EE'
,p_examples=>wwv_flow_string.join(wwv_flow_t_varchar2(
'<strong>Add entries to existing list</strong>',
'<pre><code>return [',
'  {',
'    "seq": 10,',
'    "type": "action", ',
'    "labelKey": "Label Text",',
'    "icon": "fa-pencil",',
'    "accelerator" : "",',
'    "href": "",',
'    "action": function( pMenuOptions, pTriggeringElement ){',
'      //Code to be executed when users clicks on entry',
'      return void(0);',
'    },',
'    "disabled": function( pMenuOptions, pEntry ) {',
'      //Code to be executed to determine whether entry is disabled or enabled',
'      //return true to disable list entry',
'      return true;',
'    },',
'    "hide": function( pMenuOptions ){',
'      //Code to be executed to determine whether entry is rendered',
'      //return true to hide list entry',
'      return false;',
'    }',
'  },',
'  ...',
'];</code></pre>',
'',
'<strong>Add entries with submenu to existing list</strong>',
'<pre><code>return [ ',
'  {',
'    "seq": 10,',
'    "type": "subMenu", ',
'    "labelKey": "Label Text",',
'    "icon": "fa-pencil",',
'    "accelerator" : "",',
'    "disabled": function( pMenuOptions, pEntry ) {',
'      //Code to be executed to determine whether entry is disabled or enabled',
'      //return true to disable list entry',
'      return false;',
'    },',
'    "hide": function( pMenuOptions ){',
'      //Code to be executed to determine whether entry is rendered',
'      //return true to hide list entry',
'      return false;',
'    },',
'    "items": [',
'      {',
'        "seq": 20,',
'        "type": "action", ',
'        "labelKey": "Submenu entry",',
'        "icon": "fa-search",',
'        "accelerator" : "",',
'        "href": "",',
'        "action": function( pMenuOptions, pTriggeringElement ){',
'          //Code to be executed when users clicks on entry',
'          return void(0);',
'        },',
'        "disabled": function( pMenuOptions, pEntry ) {',
'          //Code to be executed to determine whether entry is disabled or enabled',
'          //return true to disable list entry',
'          return false;',
'        },',
'        "hide": function( pMenuOptions ){',
'          //Code to be executed to determine whether entry is rendered',
'          //return true to hide list entry',
'          return false;',
'        }',
'      },',
'      ...',
'    ]',
'  },',
'  ...',
'];</code></pre>'))
,p_help_text=>wwv_flow_string.join(wwv_flow_t_varchar2(
'<p>',
'  This attribute allows to add entries to existing list defined in',
'  <i>Shared Componenets > Lists</i>. Sequence order of list entries can be ',
'  set using <strong>seq</strong> property of each new item. ',
'</p>'))
);
end;
/
begin
wwv_flow_api.g_varchar2_table := wwv_flow_api.empty_varchar2_table;
wwv_flow_api.g_varchar2_table(1) := '2E70726574697573617065786D656E756C6973742D6669786564207B0D0A2020706F736974696F6E3A20666978656421696D706F7274616E743B0D0A7D';
null;
end;
/
begin
wwv_flow_api.create_plugin_file(
 p_id=>wwv_flow_api.id(36726504509907031)
,p_plugin_id=>wwv_flow_api.id(80558907627836188)
,p_file_name=>'pretius.apexListMenu.css'
,p_mime_type=>'text/css'
,p_file_charset=>'utf-8'
,p_file_content=>wwv_flow_api.varchar2_to_blob(wwv_flow_api.g_varchar2_table)
);
end;
/
begin
wwv_flow_api.g_varchar2_table := wwv_flow_api.empty_varchar2_table;
wwv_flow_api.g_varchar2_table(1) := '242E7769646765742827707265746975732E617065784C6973744D656E75272C207B0D0A2F2F0D0A2F2F0D0A2020435F4C4F475F4445425547202020203A20617065782E64656275672E4C4F475F4C4556454C2E494E464F2C0D0A2020435F4C4F475F57';
wwv_flow_api.g_varchar2_table(2) := '41524E494E4720203A20617065782E64656275672E4C4F475F4C4556454C2E5741524E2C0D0A2020435F4C4F475F4552524F52202020203A20617065782E64656275672E4C4F475F4C4556454C2E4552524F522C0D0A2020435F4C4F475F4C4556454C36';
wwv_flow_api.g_varchar2_table(3) := '2020203A20617065782E64656275672E4C4F475F4C4556454C2E4150505F54524143452C0D0A2020435F4C4F475F4C4556454C392020203A20617065782E64656275672E4C4F475F4C4556454C2E454E47494E455F54524143452C0D0A0D0A2020435F45';
wwv_flow_api.g_varchar2_table(4) := '4E5452595F545950455F414354494F4E202020203A2027616374696F6E272C0D0A2020435F454E5452595F545950455F5355424D454E552020203A20277375624D656E75272C0D0A2020435F454E5452595F545950455F534550415241544F52203A2027';
wwv_flow_api.g_varchar2_table(5) := '736570617261746F72272C0D0A0D0A2020435F504C5547494E5F4E414D45203A202750726574697573204150455820436F6E74657874204D656E75272C0D0A0D0A20205F6372656174653A2066756E6374696F6E28297B0D0A20202020746869732E5F73';
wwv_flow_api.g_varchar2_table(6) := '757065722820746869732E6F7074696F6E7320293B0D0A0D0A20202020746869732E6C6F67507265666978203D20272320272B746869732E6F7074696F6E732E616374696F6E2E616374696F6E3B0D0A0D0A20202020617065782E64656275672E6D6573';
wwv_flow_api.g_varchar2_table(7) := '736167652820746869732E435F4C4F475F44454255472C20746869732E6C6F675072656669782C20275F637265617465272C2027746869732E6F7074696F6E73272C746869732E6F7074696F6E73293B0D0A0D0A202020206966202820746869732E6F70';
wwv_flow_api.g_varchar2_table(8) := '74696F6E732E6C6973742E74797065203D3D202753514C5F515545525927207C7C20746869732E6F7074696F6E732E6C6973742E74797065203D3D202746554E4354494F4E5F52455455524E494E475F53514C5F515545525927202920207B0D0A202020';
wwv_flow_api.g_varchar2_table(9) := '202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F44454255472C20746869732E6C6F675072656669782C20275F637265617465272C2027636F6E766572742064796E616D6963206C6973742071756572792072657375';
wwv_flow_api.g_varchar2_table(10) := '6C7427293B0D0A202020202020746869732E6F7074696F6E732E6C6973742E656E7472696573203D20746869732E5F636F6E766572744F626A65637428293B0D0A202020207D0D0A0D0A202020200D0A20202020746869732E756E69717565496420203D';
wwv_flow_api.g_varchar2_table(11) := '202428273C6469763E3C2F6469763E27292E756E69717565496428292E617474722827696427293B0D0A20202020746869732E6576656E744E616D6553706163652020203D20746869732E6F7074696F6E732E616374696F6E2E616374696F6E2B272D27';
wwv_flow_api.g_varchar2_table(12) := '2B746869732E756E6971756549643B0D0A0D0A0D0A20202020746869732E657874656E644A534F4E2020203D20746869732E5F676574457874656E644A736F6E28293B0D0A20202020746869732E6578747261456E7472696573203D20746869732E5F67';
wwv_flow_api.g_varchar2_table(13) := '65744578747261456E747269657328293B202020200D0A0D0A20202020746869732E6D656E75436F6E666967203D20746869732E5F617065784372656174654D656E754A736F6E28293B0D0A0D0A20202020746869732E6D656E75436F6E7461696E6572';
wwv_flow_api.g_varchar2_table(14) := '203D20746869732E5F6372656174654D656E75436F6E7461696E657228293B0D0A202020200D0A202020206966202820746869732E656C656D656E7420213D20646F63756D656E742029207B0D0A202020202020746869732E656C656D656E740D0A2020';
wwv_flow_api.g_varchar2_table(15) := '2020202020202E61747472287B0D0A2020202020202020202022646174612D6D656E75223A20746869732E756E6971756549642C0D0A2020202020202020202022617269612D686173706F707570223A20747275652C0D0A202020202020202020202261';
wwv_flow_api.g_varchar2_table(16) := '7269612D657870616E646564223A2066616C73650D0A20202020202020207D290D0A20202020202020202E616464436C61737328276A732D6D656E75427574746F6E27293B0D0A202020207D0D0A0D0A20202020746869732E6D656E75436F6E7461696E';
wwv_flow_api.g_varchar2_table(17) := '65722E617070656E64546F2822626F647922293B0D0A0D0A20202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F44454255472C20746869732E6C6F675072656669782C20275F637265617465272C2027696E69742041';
wwv_flow_api.g_varchar2_table(18) := '504558206D656E75206F6E20656C656D656E7427293B0D0A20202020746869732E6D656E75436F6E7461696E65722E6D656E752820746869732E6D656E75436F6E66696720293B0D0A2020202020200D0A20202020746869732E61706578427574746F6E';
wwv_flow_api.g_varchar2_table(19) := '203D20747275653B0D0A0D0A20202020696620282021746869732E656C656D656E742E69732827627574746F6E2729207C7C20746869732E656C656D656E742E69732827627574746F6E272920262620746869732E656C656D656E742E61747472282769';
wwv_flow_api.g_varchar2_table(20) := '642729203D3D20756E646566696E65642029207B0D0A202020202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F44454255472C20746869732E6C6F675072656669782C20275F637265617465272C2027696E76616C69';
wwv_flow_api.g_varchar2_table(21) := '6420627574746F6E2C20666F7263652073686F7727293B0D0A202020202020746869732E61706578427574746F6E203D2066616C73653B0D0A202020202020746869732E73686F7728293B0D0A202020207D0D0A20207D2C0D0A0D0A2F2F0D0A2F2F0D0A';
wwv_flow_api.g_varchar2_table(22) := '20205F64657374726F793A2066756E6374696F6E28297B0D0A202020202F2F75737577616A2077737A7973746B6965206E61646D6961726F776520656C656D656E74792069206D656E75206B746F7265206F7361647A696C6573207720626F64790D0A0D';
wwv_flow_api.g_varchar2_table(23) := '0A202020207472797B0D0A202020202020746869732E6D656E75436F6E7461696E65722E72656D6F766528293B20200D0A202020207D2063617463682820704572726F7220297B0D0A202020202020617065782E64656275672E6D657373616765282074';
wwv_flow_api.g_varchar2_table(24) := '6869732E435F4C4F475F4552524F522C20746869732E6C6F675072656669782C20275F64657374726F79272C20704572726F722E6D657373616765293B0D0A202020207D0D0A202020200D0A202020207472797B0D0A202020202020746869732E656C65';
wwv_flow_api.g_varchar2_table(25) := '6D656E742E72656D6F7665436C617373282769732D61637469766527292020202020200D0A202020202020746869732E656C656D656E742E72656D6F7665417474722827646174612D6D656E7527293B0D0A202020202020746869732E656C656D656E74';
wwv_flow_api.g_varchar2_table(26) := '2E72656D6F7665417474722827617269612D686173706F70757027293B0D0A202020202020746869732E656C656D656E742E72656D6F7665417474722827617269612D657870616E64656427293B0D0A0D0A202020202020746869732E656C656D656E74';
wwv_flow_api.g_varchar2_table(27) := '2E72656D6F7665436C61737328276A732D6D656E75427574746F6E27293B0D0A202020200D0A202020207D63617463682820704572726F722029207B0D0A202020202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F45';
wwv_flow_api.g_varchar2_table(28) := '52524F522C20746869732E6C6F675072656669782C20275F64657374726F79272C20704572726F722E6D657373616765293B0D0A202020207D0D0A0D0A20207D2C0D0A2F2F0D0A2F2F0D0A20205F7365744F7074696F6E3A2066756E6374696F6E282070';
wwv_flow_api.g_varchar2_table(29) := '4B65792C207056616C75652029207B0D0A202020206966202820704B6579203D3D3D202276616C7565222029207B0D0A2020202020207056616C7565203D20746869732E5F636F6E73747261696E28207056616C756520293B0D0A202020207D0D0A0D0A';
wwv_flow_api.g_varchar2_table(30) := '20202020746869732E5F73757065722820704B65792C207056616C756520293B0D0A20207D2C20200D0A20206F7074696F6E733A2066756E6374696F6E2820704F7074696F6E7320297B0D0A20202020746869732E5F73757065722820704F7074696F6E';
wwv_flow_api.g_varchar2_table(31) := '7320293B0D0A20207D2C0D0A2F2F0D0A2F2F0D0A20205F7365744F7074696F6E733A2066756E6374696F6E2820704F7074696F6E732029207B0D0A20202020746869732E5F73757065722820704F7074696F6E7320293B0D0A20207D2C0D0A2F2F0D0A2F';
wwv_flow_api.g_varchar2_table(32) := '2F0D0A20205F6372656174654D656E75436F6E7461696E65723A2066756E6374696F6E28297B0D0A20202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F44454255472C20746869732E6C6F675072656669782C20275F';
wwv_flow_api.g_varchar2_table(33) := '6372656174654D656E75436F6E7461696E657227293B0D0A0D0A2020202076617220646976203D20242820273C6469762069643D22272B746869732E756E6971756549642B27223E3C2F6469763E2720293B0D0A0D0A202020206966202820746869732E';
wwv_flow_api.g_varchar2_table(34) := '6F7074696F6E732E616374696F6E2E61747472696275746530322E696E6465784F66282746502729203E202D312029207B0D0A2020202020206469762E616464436C617373282770726574697573617065786D656E756C6973742D666978656427293B0D';
wwv_flow_api.g_varchar2_table(35) := '0A202020207D0D0A0D0A2020202072657475726E206469763B0D0A20207D2C0D0A20205F6765744578747261456E74726965733A2066756E6374696F6E28297B0D0A20202020766172200D0A20202020202066756E632C0D0A20202020202066756E6342';
wwv_flow_api.g_varchar2_table(36) := '6F6479203D2022222C0D0A202020202020726573756C74203D205B5D3B0D0A0D0A202020206966202820746869732E6F7074696F6E732E616374696F6E2E61747472696275746530322E696E6465784F66282745452729203E202D312029207B0D0A2020';
wwv_flow_api.g_varchar2_table(37) := '20202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F44454255472C20746869732E6C6F675072656669782C20275F6765744578747261456E747269657327293B0D0A0D0A202020202020747279207B0D0A2020202020';
wwv_flow_api.g_varchar2_table(38) := '20202066756E63426F6479203D2022222B0D0A2020202020202020202022746869732E74726967676572696E67456C656D656E74203D207054726967676572696E67456C656D656E743B205C6E222B0D0A2020202020202020202022746869732E616666';
wwv_flow_api.g_varchar2_table(39) := '6563746564456C656D656E7473203D20706166666563746564456C656D656E74733B205C6E222B0D0A2020202020202020202022222B746869732E6F7074696F6E732E616374696F6E2E61747472696275746530342B225C6E222B0D0A20202020202020';
wwv_flow_api.g_varchar2_table(40) := '20202022223B0D0A202020202020202066756E63203D206E65772046756E6374696F6E2820227054726967676572696E67456C656D656E74222C2022706166666563746564456C656D656E7473222C2066756E63426F647920293B0D0A20202020202020';
wwv_flow_api.g_varchar2_table(41) := '20726573756C74203D2066756E632E63616C6C2820746869732C20746869732E6F7074696F6E732E74726967676572696E67456C656D656E742C20746869732E6F7074696F6E732E6166666563746564456C656D656E747320293B0D0A20202020202020';
wwv_flow_api.g_varchar2_table(42) := '0D0A0D0A2020202020202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F4C4556454C362C20746869732E6C6F675072656669782C20275F6765744578747261456E7472696573272C2027726573756C74272C20726573';
wwv_flow_api.g_varchar2_table(43) := '756C74293B20202020202020200D0A0D0A2020202020202020666F72202820766172206920696E20726573756C742029207B0D0A20202020202020202020726573756C745B695D2E534551203D20726573756C745B695D2E7365713B0D0A202020202020';
wwv_flow_api.g_varchar2_table(44) := '2020202064656C65746520726573756C745B695D2E7365713B0D0A20202020202020207D0D0A0D0A20202020202020206966202820726573756C74203D3D20756E646566696E65642029207B0D0A202020202020202020202F2F6E6F20726573756C7420';
wwv_flow_api.g_varchar2_table(45) := '66726F6D2066756E6374696F6E0D0A20202020202020202020746869732E5F7468726F774572726F72282027457874726120456E74726965732072657475726E656420756E646566696E65642720293B0D0A20202020202020207D0D0A0D0A2020202020';
wwv_flow_api.g_varchar2_table(46) := '207D2063617463682820704572726F722029207B0D0A2020202020202020746869732E5F7072696E7446756E6374696F6E546F436F6E736F6C6528746869732E6F7074696F6E732E616374696F6E2E6174747269627574653034293B0D0A202020202020';
wwv_flow_api.g_varchar2_table(47) := '2020746869732E5F7468726F774572726F72282027457874726120656E7472696573206D656E75206572726F723A20272B704572726F722E6D65737361676520293B0D0A2020202020207D0D0A202020207D0D0A0D0A202020200D0A2020202072657475';
wwv_flow_api.g_varchar2_table(48) := '726E20726573756C743B0D0A20207D2C0D0A20205F636865636B457874656E644A736F6E3A2066756E6374696F6E2820704C6973742C2070496420297B0D0A20202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F4C45';
wwv_flow_api.g_varchar2_table(49) := '56454C362C20746869732E6C6F675072656669782C20275F636865636B457874656E644A736F6E27293B0D0A20202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F4C4556454C362C20746869732E6C6F675072656669';
wwv_flow_api.g_varchar2_table(50) := '782C20275F636865636B457874656E644A736F6E206C697374272C20704C697374293B20202020202020200D0A20202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F4C4556454C362C20746869732E6C6F6750726566';
wwv_flow_api.g_varchar2_table(51) := '69782C20275F636865636B457874656E644A736F6E20617474723130272C20704964293B0D0A0D0A2020202076617220666F756E64203D2066616C73653B0D0A0D0A20202020666F72202820766172206920696E20704C69737429207B0D0A2020202020';
wwv_flow_api.g_varchar2_table(52) := '206966202820704C6973745B695D2E454E5452595F4154545249425554455F3031203D3D207049642029207B0D0A2020202020202020666F756E64203D20747275653B0D0A2020202020202020627265616B3B0D0A2020202020207D0D0A0D0A20202020';
wwv_flow_api.g_varchar2_table(53) := '20206966202820704C6973745B695D2E6974656D7320213D20756E646566696E656420262620704C6973745B695D2E6974656D7320696E7374616E63656F6620417272617929207B0D0A2020202020202020666F756E64203D20746869732E5F63686563';
wwv_flow_api.g_varchar2_table(54) := '6B457874656E644A736F6E2820704C6973745B695D2E6974656D732C2070496420293B0D0A2020202020207D0D0A202020207D0D0A0D0A2020202072657475726E20666F756E643B0D0A20207D2C0D0A20205F676574457874656E644A736F6E3A206675';
wwv_flow_api.g_varchar2_table(55) := '6E6374696F6E28297B0D0A20202020766172200D0A20202020202066756E632C0D0A20202020202066756E63426F6479203D2022222C0D0A202020202020726573756C74203D207B7D2C0D0A2020202020206C697374436F7079203D20242E657874656E';
wwv_flow_api.g_varchar2_table(56) := '64285B5D2C20746869732E6F7074696F6E732E6C6973742E656E7472696573292C0D0A202020202020636865636B526573756C743B0D0A2020202020200D0A0D0A202020206966202820746869732E6F7074696F6E732E616374696F6E2E617474726962';
wwv_flow_api.g_varchar2_table(57) := '75746530322E696E6465784F6628274F4D422729203E202D312029207B0D0A202020202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F44454255472C20746869732E6C6F675072656669782C20275F67657445787465';
wwv_flow_api.g_varchar2_table(58) := '6E644A736F6E27293B2020202020200D0A0D0A2020202020207472797B0D0A202020202020202066756E63426F6479203D2022222B0D0A2020202020202020202022746869732E74726967676572696E67456C656D656E74203D20705472696767657269';
wwv_flow_api.g_varchar2_table(59) := '6E67456C656D656E743B205C6E222B0D0A2020202020202020202022746869732E6166666563746564456C656D656E7473203D20706166666563746564456C656D656E74733B205C6E222B0D0A2020202020202020202022222B746869732E6F7074696F';
wwv_flow_api.g_varchar2_table(60) := '6E732E616374696F6E2E61747472696275746530332B225C6E222B0D0A2020202020202020202022223B0D0A202020202020202066756E63203D206E65772046756E6374696F6E2820227054726967676572696E67456C656D656E74222C202270616666';
wwv_flow_api.g_varchar2_table(61) := '6563746564456C656D656E7473222C2066756E63426F647920293B0D0A2020202020202020726573756C74203D2066756E632E63616C6C2820746869732C20746869732E6F7074696F6E732E74726967676572696E67456C656D656E742C20746869732E';
wwv_flow_api.g_varchar2_table(62) := '6F7074696F6E732E6166666563746564456C656D656E747320293B0D0A2020202020207D2063617463682820704572726F722029207B0D0A2020202020202020746869732E5F7072696E7446756E6374696F6E546F436F6E736F6C6528746869732E6F70';
wwv_flow_api.g_varchar2_table(63) := '74696F6E732E616374696F6E2E6174747269627574653033293B0D0A2020202020202020746869732E5F7468726F774572726F72282027457874656E64696E67206D656E75206572726F723A20272B704572726F722E6D65737361676520293B0D0A2020';
wwv_flow_api.g_varchar2_table(64) := '202020207D0D0A0D0A202020202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F4C4556454C362C20746869732E6C6F675072656669782C20275F676574457874656E644A736F6E20726573756C74272C20726573756C';
wwv_flow_api.g_varchar2_table(65) := '74293B0D0A0D0A20202020202069662028202128726573756C7420696E7374616E63656F66204F626A65637429207C7C20726573756C7420696E7374616E63656F662041727261792029207B0D0A2020202020202020746869732E5F7468726F77457272';
wwv_flow_api.g_varchar2_table(66) := '6F722820274F76657272696465204265686176696F75722072657475726E656420696E76616C6964206F626A6563742E2720293B0D0A2020202020207D0D0A0D0A2020202020202F2F636865636B2069662069647320726570726573656E7473206C6973';
wwv_flow_api.g_varchar2_table(67) := '74730D0A202020202020666F72202820766172206920696E20726573756C742029207B0D0A2020202020202020636865636B526573756C74203D20746869732E5F636865636B457874656E644A736F6E28206C697374436F70792C206920293B0D0A0D0A';
wwv_flow_api.g_varchar2_table(68) := '2020202020202020696620282021636865636B526573756C742029207B0D0A20202020202020202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F5741524E494E472C20746869732E6C6F675072656669782C20275F67';
wwv_flow_api.g_varchar2_table(69) := '6574457874656E644A736F6E207468657265206973206E6F20656E74727920776974682061747472696275746520312073657420746F2022272B692B272227293B0D0A20202020202020207D0D0A2020202020207D0D0A202020207D0D0A0D0A20202020';
wwv_flow_api.g_varchar2_table(70) := '72657475726E20726573756C743B0D0A20207D2C0D0A20205F6170657843616C6C6261636B4166746572436C6F73653A2066756E6374696F6E2820704576656E742C2070556920297B0D0A20202020617065782E64656275672E6D657373616765282074';
wwv_flow_api.g_varchar2_table(71) := '6869732E435F4C4F475F44454255472C2020746869732E6C6F675072656669782C20275F6170657843616C6C6261636B4166746572436C6F736527293B0D0A20202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F4C45';
wwv_flow_api.g_varchar2_table(72) := '56454C362C20746869732E6C6F675072656669782C20275F6170657843616C6C6261636B4166746572436C6F7365272C2027704576656E74272C20704576656E74293B0D0A20202020617065782E64656275672E6D6573736167652820746869732E435F';
wwv_flow_api.g_varchar2_table(73) := '4C4F475F4C4556454C362C20746869732E6C6F675072656669782C20275F6170657843616C6C6261636B4166746572436C6F7365272C2027705569272020202C20705569293B0D0A0D0A20202020746869732E64657374726F7928293B0D0A20207D2C0D';
wwv_flow_api.g_varchar2_table(74) := '0A20205F6170657843616C6C6261636B4265666F72654F70656E3A2066756E6374696F6E2820704576656E742C2070556920297B0D0A20202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F44454255472C2020746869';
wwv_flow_api.g_varchar2_table(75) := '732E6C6F675072656669782C20275F6170657843616C6C6261636B4265666F72654F70656E27293B0D0A20202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F4C4556454C362C20746869732E6C6F675072656669782C';
wwv_flow_api.g_varchar2_table(76) := '20275F6170657843616C6C6261636B4265666F72654F70656E272C2027704576656E74272C20704576656E74293B0D0A20202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F4C4556454C362C20746869732E6C6F6750';
wwv_flow_api.g_varchar2_table(77) := '72656669782C20275F6170657843616C6C6261636B4265666F72654F70656E272C2027705569272020202C20705569293B0D0A0D0A202020206966202820746869732E61706578427574746F6E203D3D2066616C73652029207B0D0A2020202020207468';
wwv_flow_api.g_varchar2_table(78) := '69732E656C656D656E742E616464436C617373282769732D61637469766527290D0A202020207D0D0A20207D2C0D0A20205F6170657843616C6C6261636B4372656174653A2066756E6374696F6E2820704576656E742C2070556920297B0D0A20202020';
wwv_flow_api.g_varchar2_table(79) := '617065782E64656275672E6D6573736167652820746869732E435F4C4F475F44454255472C2020746869732E6C6F675072656669782C20275F6170657843616C6C6261636B43726561746527293B0D0A20202020617065782E64656275672E6D65737361';
wwv_flow_api.g_varchar2_table(80) := '67652820746869732E435F4C4F475F4C4556454C362C20746869732E6C6F675072656669782C20275F6170657843616C6C6261636B437265617465272C2027704576656E74272C20704576656E74293B0D0A20202020617065782E64656275672E6D6573';
wwv_flow_api.g_varchar2_table(81) := '736167652820746869732E435F4C4F475F4C4556454C362C20746869732E6C6F675072656669782C20275F6170657843616C6C6261636B437265617465272C2027705569272020202C20705569293B0D0A20207D2C0D0A20202F2F68747470733A2F2F73';
wwv_flow_api.g_varchar2_table(82) := '7461636B6F766572666C6F772E636F6D2F7175657374696F6E732F313132393231362F736F72742D61727261792D6F662D6F626A656374732D62792D737472696E672D70726F70657274792D76616C75650D0A20205F736F727441727261793A2066756E';
wwv_flow_api.g_varchar2_table(83) := '6374696F6E28207050726F70657274792029207B0D0A2020202076617220736F72744F72646572203D20313B0D0A0D0A202020207050726F7065727479203D207050726F70657274792E746F55707065724361736528293B0D0A0D0A2020202069662870';
wwv_flow_api.g_varchar2_table(84) := '50726F70657274795B305D203D3D3D20222D2229207B0D0A2020202020202020736F72744F72646572203D202D313B0D0A20202020202020207050726F7065727479203D207050726F70657274792E7375627374722831293B0D0A202020207D0D0A2020';
wwv_flow_api.g_varchar2_table(85) := '202072657475726E2066756E6374696F6E2028612C6229207B0D0A202020202020202076617220726573756C74203D2028615B7050726F70657274795D203C20625B7050726F70657274795D29203F202D31203A2028615B7050726F70657274795D203E';
wwv_flow_api.g_varchar2_table(86) := '20625B7050726F70657274795D29203F2031203A20303B0D0A202020202020202072657475726E20726573756C74202A20736F72744F726465723B0D0A202020207D202020200D0A20207D2C0D0A20205F617065784372656174654D656E754A736F6E3A';
wwv_flow_api.g_varchar2_table(87) := '2066756E6374696F6E28297B0D0A20202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F44454255472C20746869732E6C6F675072656669782C20275F617065784372656174654D656E754A736F6E27293B0D0A0D0A20';
wwv_flow_api.g_varchar2_table(88) := '202020766172200D0A2020202020206D656E75203D207B0D0A20202020202020206166746572436C6F73653A20242E70726F78792820746869732E5F6170657843616C6C6261636B4166746572436C6F73652C2074686973292C0D0A2020202020202020';
wwv_flow_api.g_varchar2_table(89) := '6265666F72654F70656E3A20242E70726F78792820746869732E5F6170657843616C6C6261636B4265666F72654F70656E2C2074686973292C0D0A2020202020202020637265617465202020203A20242E70726F78792820746869732E5F617065784361';
wwv_flow_api.g_varchar2_table(90) := '6C6C6261636B4372656174652C2074686973292C0D0A202020202020202069636F6E5479706520203A20226661220D0A2020202020207D2C0D0A2020202020206C697374436F7079203D20242E657874656E64285B5D2C20746869732E6F7074696F6E73';
wwv_flow_api.g_varchar2_table(91) := '2E6C6973742E656E7472696573292C0D0A20202020202072656D6F7665643B0D0A0D0A2F2A0D0A202020202F2F72656D6F7665206C69737420656E7472696573207768657265206174747269627574652030332069732073657420746F20747275650D0A';
wwv_flow_api.g_varchar2_table(92) := '20202020666F72202820766172206920696E206C697374436F70792029207B0D0A20202020202069662028206C697374436F70795B695D2E454E5452595F4154545249425554455F3033203D3D2022747275652229207B0D0A202020202020202072656D';
wwv_flow_api.g_varchar2_table(93) := '6F766564203D206C697374436F70792E73706C69636528692C2031293B0D0A2020202020202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F5741524E494E472C20746869732E6C6F675072656669782C20275F617065';
wwv_flow_api.g_varchar2_table(94) := '784372656174654D656E754A736F6E272C202772656D6F76696E6720656E7472792022272B72656D6F7665645B305D2E454E5452595F544558542B27222062656361757365206974732068696464656E2076696120413033272C2072656D6F766564293B';
wwv_flow_api.g_varchar2_table(95) := '0D0A2020202020207D0D0A202020207D0D0A2A2F202020200D0A0D0A20202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F4C4556454C362C20746869732E6C6F675072656669782C20275F617065784372656174654D';
wwv_flow_api.g_varchar2_table(96) := '656E754A736F6E272C202763757272656E74206C697374272C20242E657874656E64285B5D2C206C697374436F707929293B0D0A0D0A202020206C697374436F7079203D206C697374436F70792E636F6E6361742820746869732E6578747261456E7472';
wwv_flow_api.g_varchar2_table(97) := '69657320293B0D0A0D0A20202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F4C4556454C362C20746869732E6C6F675072656669782C20275F617065784372656174654D656E754A736F6E272C2027657874656E6465';
wwv_flow_api.g_varchar2_table(98) := '64207769746820657874726120656E7472696573272C20242E657874656E64285B5D2C206C697374436F707929293B0D0A0D0A202020206C697374436F70792E736F72742820746869732E5F736F727441727261792827736571272920293B0D0A0D0A20';
wwv_flow_api.g_varchar2_table(99) := '202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F4C4556454C362C20746869732E6C6F675072656669782C20275F617065784372656174654D656E754A736F6E272C2027736F72746564272C20242E657874656E6428';
wwv_flow_api.g_varchar2_table(100) := '5B5D2C206C697374436F707929293B0D0A0D0A202020206D656E752E6974656D73203D20746869732E5F617065784372656174654D656E75456E747269657328206C697374436F707920293B0D0A0D0A20202020617065782E64656275672E6D65737361';
wwv_flow_api.g_varchar2_table(101) := '67652820746869732E435F4C4F475F4C4556454C362C20746869732E6C6F675072656669782C20275F617065784372656174654D656E754A736F6E272C20276F7574206D656E75272C206D656E75293B0D0A0D0A2020202072657475726E206D656E753B';
wwv_flow_api.g_varchar2_table(102) := '0D0A20207D2C0D0A20205F617065784372656174654D656E75456E74726965733A2066756E6374696F6E2820704C69737420297B0D0A20202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F44454255472C2020746869';
wwv_flow_api.g_varchar2_table(103) := '732E6C6F675072656669782C20275F617065784372656174654D656E75456E747269657327293B0D0A20202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F4C4556454C362C20746869732E6C6F675072656669782C20';
wwv_flow_api.g_varchar2_table(104) := '275F617065784372656174654D656E75456E7472696573272C20704C697374293B0D0A202020200D0A20202020766172200D0A202020202020656E74726965734172726179203D205B5D2C0D0A202020202020656E747279203D207B7D3B0D0A0D0A2020';
wwv_flow_api.g_varchar2_table(105) := '2020666F7220282076617220693D303B2069203C20704C6973742E6C656E6774683B20692B2B20297B0D0A202020202020656E747269657341727261792E707573682820746869732E5F617065784372656174654D656E75456E7472792820704C697374';
wwv_flow_api.g_varchar2_table(106) := '5B695D202920293B0D0A202020207D0D0A0D0A20202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F44454255472C2020746869732E6C6F675072656669782C20275F617065784372656174654D656E75456E74726965';
wwv_flow_api.g_varchar2_table(107) := '73206F7574272C20656E74726965734172726179293B0D0A0D0A0D0A2020202072657475726E20656E747269657341727261793B0D0A202020200D0A20207D2C0D0A20205F617065784765744D656E754974656D547970653A2066756E6374696F6E2820';
wwv_flow_api.g_varchar2_table(108) := '70456E74727920297B0D0A20202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F4C4556454C362C20746869732E6C6F675072656669782C20275F617065784765744D656E754974656D54797065272C2070456E747279';
wwv_flow_api.g_varchar2_table(109) := '293B0D0A0D0A20202020696620282070456E7472792E454E5452595F4154545249425554455F3037203D3D2027736570617261746F72272029207B0D0A20202020202072657475726E20746869732E435F454E5452595F545950455F534550415241544F';
wwv_flow_api.g_varchar2_table(110) := '523B0D0A202020207D0D0A20202020656C736520696620282070456E7472792E6974656D7320213D20756E646566696E65642029207B0D0A20202020202072657475726E20746869732E435F454E5452595F545950455F5355424D454E553B0D0A202020';
wwv_flow_api.g_varchar2_table(111) := '207D0D0A20202020656C7365207B0D0A20202020202072657475726E20746869732E435F454E5452595F545950455F414354494F4E3B0D0A202020207D0D0A20207D2C0D0A20205F617065784372656174654D656E75456E7472793A2066756E6374696F';
wwv_flow_api.g_varchar2_table(112) := '6E282070456E74727920297B0D0A20202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F44454255472C20746869732E6C6F675072656669782C20275F617065784372656174654D656E75456E7472792022272B70456E';
wwv_flow_api.g_varchar2_table(113) := '7472792E454E5452595F544558542B272227293B0D0A20202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F4C4556454C362C20746869732E6C6F675072656669782C20275F617065784372656174654D656E75456E74';
wwv_flow_api.g_varchar2_table(114) := '7279272C2070456E747279293B0D0A0D0A0D0A202020202F2F6974656D730D0A20202020766172200D0A202020202020656E747279203D207B7D2C0D0A20202020202074797065203D20746869732E5F617065784765744D656E754974656D5479706528';
wwv_flow_api.g_varchar2_table(115) := '2070456E74727920293B200D0A0D0A20202020656E747279203D207B0D0A20202020202074797065202020202020203A20747970652C0D0A2020202020206C6162656C4B65792020203A2070456E7472792E454E5452595F544558542020202020202020';
wwv_flow_api.g_varchar2_table(116) := '203D3D20756E646566696E6564203F2070456E7472792E6C6162656C4B6579202020202020203A2070456E7472792E454E5452595F544558542C0D0A2020202020206C6162656C2020202020203A2070456E7472792E454E5452595F5445585420202020';
wwv_flow_api.g_varchar2_table(117) := '20202020203D3D20756E646566696E6564203F2070456E7472792E6C6162656C202020202020202020203A2070456E7472792E454E5452595F544558542C0D0A20202020202069636F6E202020202020203A2070456E7472792E454E5452595F494D4147';
wwv_flow_api.g_varchar2_table(118) := '4520202020202020203D3D20756E646566696E6564203F2070456E7472792E69636F6E20202020202020202020203A2070456E7472792E454E5452595F494D4147452C0D0A20202020202069636F6E5374796C6520203A2070456E7472792E69636F6E53';
wwv_flow_api.g_varchar2_table(119) := '74796C652C0D0A202020202020616363656C657261746F723A2070456E7472792E454E5452595F4154545249425554455F3036203D3D20756E646566696E6564203F2070456E7472792E616363656C657261746F72202020203A2070456E7472792E454E';
wwv_flow_api.g_varchar2_table(120) := '5452595F4154545249425554455F30362C0D0A20202020202068726566202020202020203A2070456E7472792E454E5452595F544152474554202020202020203D3D20756E646566696E6564203F2070456E7472792E6872656620202020202020202020';
wwv_flow_api.g_varchar2_table(121) := '203A2070456E7472792E454E5452595F5441524745542C0D0A20202020202069642020202020202020203A2070456E7472792E454E5452595F4154545249425554455F3031203D3D20756E646566696E6564203F20756E646566696E6564202020202020';
wwv_flow_api.g_varchar2_table(122) := '202020202020203A2070456E7472792E454E5452595F4154545249425554455F30312C0D0A202020202020616374696F6E20202020203A2070456E7472792E616374696F6E2C0D0A20202020202064697361626C65642020203A2070456E7472792E6469';
wwv_flow_api.g_varchar2_table(123) := '7361626C65642C0D0A20202020202068696465202020202020203A2070456E7472792E686964650D0A202020207D3B0D0A0D0A20202020696620282074797065203D3D20746869732E435F454E5452595F545950455F5355424D454E552029207B0D0A20';
wwv_flow_api.g_varchar2_table(124) := '2020202020656E7472792E6D656E75203D207B0D0A20202020202020202269636F6E54797065223A20226661222C0D0A2020202020202020226974656D73223A20746869732E5F617065784372656174654D656E75456E7472696573282070456E747279';
wwv_flow_api.g_varchar2_table(125) := '2E6974656D7320290D0A2020202020207D0D0A202020207D0D0A0D0A202020206966202820746869732E657874656E644A534F4E5B20656E7472792E6964205D20213D20756E646566696E65642029207B0D0A202020202020617065782E64656275672E';
wwv_flow_api.g_varchar2_table(126) := '6D6573736167652820746869732E435F4C4F475F4C4556454C362C20746869732E6C6F675072656669782C20275F617065784372656174654D656E75456E74727920657874656E6420656E74727920616374696F6E272C2070456E747279293B0D0A0D0A';
wwv_flow_api.g_varchar2_table(127) := '202020202020656E7472792E616374696F6E203D20746869732E657874656E644A534F4E5B20656E7472792E6964205D2E616374696F6E3B0D0A0D0A2020202020202F2F64697361626C650D0A202020202020696620282070456E7472792E454E545259';
wwv_flow_api.g_varchar2_table(128) := '5F4154545249425554455F3032203D3D2022747275652220262620746869732E657874656E644A534F4E5B20656E7472792E6964205D2E64697361626C6564203D3D20756E646566696E656429207B0D0A2020202020202020617065782E64656275672E';
wwv_flow_api.g_varchar2_table(129) := '6D6573736167652820746869732E435F4C4F475F4C4556454C362C20746869732E6C6F675072656669782C20275F617065784372656174654D656E75456E7472792064697361626C6520656E747279206261736564206F6E20656E747279206174747269';
wwv_flow_api.g_varchar2_table(130) := '62757465283229206265636175736520657874656E64204A534F4E20646F65736E5C277420686176652064697361626C65642070726F7065727479272C2070456E747279293B0D0A2020202020202020656E7472792E64697361626C6564203D20747275';
wwv_flow_api.g_varchar2_table(131) := '653B0D0A2020202020207D200D0A202020202020656C7365206966202820746869732E657874656E644A534F4E5B20656E7472792E6964205D2E64697361626C656420213D20756E646566696E65642029207B0D0A2020202020202020617065782E6465';
wwv_flow_api.g_varchar2_table(132) := '6275672E6D6573736167652820746869732E435F4C4F475F4C4556454C362C20746869732E6C6F675072656669782C20275F617065784372656174654D656E75456E7472792064697361626C65202F20656E61626C6520656E747279206261736564206F';
wwv_flow_api.g_varchar2_table(133) := '6E20656E7472792064697361626C652066756E6374696F6E20726573756C74272C2070456E747279293B0D0A2020202020202020656E7472792E64697361626C6564203D20746869732E657874656E644A534F4E5B20656E7472792E6964205D2E646973';
wwv_flow_api.g_varchar2_table(134) := '61626C65643B202020200D0A2020202020207D0D0A202020202020656C7365207B0D0A2020202020202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F4C4556454C362C20746869732E6C6F675072656669782C20275F';
wwv_flow_api.g_varchar2_table(135) := '617065784372656174654D656E75456E74727920656E747279206973206E6F742064697361626C6564272C2070456E747279293B0D0A2020202020202020656E7472792E64697361626C6564203D2066616C73653B0D0A2020202020207D200D0A0D0A20';
wwv_flow_api.g_varchar2_table(136) := '20202020202F2F686964650D0A202020202020696620282070456E7472792E454E5452595F4154545249425554455F3033203D3D2022747275652220262620746869732E657874656E644A534F4E5B20656E7472792E6964205D2E68696465203D3D2075';
wwv_flow_api.g_varchar2_table(137) := '6E646566696E656429207B0D0A2020202020202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F4C4556454C362C20746869732E6C6F675072656669782C20275F617065784372656174654D656E75456E747279206869';
wwv_flow_api.g_varchar2_table(138) := '646520656E747279206261736564206F6E20656E74727920617474726962757465283329206265636175736520657874656E64204A534F4E20646F65736E5C2774206861766520686964652070726F7065727479272C2070456E747279293B0D0A202020';
wwv_flow_api.g_varchar2_table(139) := '2020202020656E7472792E68696465203D20747275653B0D0A2020202020207D200D0A202020202020656C7365206966202820746869732E657874656E644A534F4E5B20656E7472792E6964205D2E6869646520213D20756E646566696E65642029207B';
wwv_flow_api.g_varchar2_table(140) := '0D0A2020202020202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F4C4556454C362C20746869732E6C6F675072656669782C20275F617065784372656174654D656E75456E7472792068696465202F2073686F772065';
wwv_flow_api.g_varchar2_table(141) := '6E747279206261736564206F6E20656E74727920686964652066756E6374696F6E20726573756C74272C2070456E747279293B0D0A2020202020202020656E7472792E68696465203D20746869732E657874656E644A534F4E5B20656E7472792E696420';
wwv_flow_api.g_varchar2_table(142) := '5D2E686964653B202020200D0A2020202020207D0D0A202020202020656C7365207B0D0A2020202020202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F4C4556454C362C20746869732E6C6F675072656669782C2027';
wwv_flow_api.g_varchar2_table(143) := '5F617065784372656174654D656E75456E74727920656E747279206973206E6F742068696464656E272C2070456E747279293B0D0A2020202020202020656E7472792E68696465203D2066616C73653B0D0A2020202020207D200D0A0D0A202020202020';
wwv_flow_api.g_varchar2_table(144) := '2F2F7375626D656E750D0A2020202020206966202820746869732E657874656E644A534F4E5B20656E7472792E6964205D2E6974656D7320213D20756E646566696E656420262620746869732E657874656E644A534F4E5B20656E7472792E6964205D2E';
wwv_flow_api.g_varchar2_table(145) := '6974656D732E6C656E677468203E20302029207B0D0A2020202020202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F4C4556454C362C20746869732E6C6F675072656669782C20275F617065784372656174654D656E';
wwv_flow_api.g_varchar2_table(146) := '75456E74727920656E74727920686173207375626D656E752066726F6D20657874656E646564204A534F4E272C2070456E747279293B0D0A0D0A2020202020202020656E7472792E6D656E75203D207B0D0A202020202020202020202269636F6E547970';
wwv_flow_api.g_varchar2_table(147) := '65223A20226661222C0D0A20202020202020202020226974656D73223A20746869732E5F617065784372656174654D656E75456E74726965732820746869732E657874656E644A534F4E5B20656E7472792E6964205D2E6974656D7320290D0A20202020';
wwv_flow_api.g_varchar2_table(148) := '202020207D0D0A0D0A20202020202020202F2F6368616E676520656E747279207479706520746F207375626D656E750D0A2020202020202020656E7472792E74797065203D20746869732E435F454E5452595F545950455F5355424D454E553B0D0A2020';
wwv_flow_api.g_varchar2_table(149) := '202020207D0D0A20200D0A202020207D0D0A20202020656C7365207B0D0A202020202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F4C4556454C362C20746869732E6C6F675072656669782C20275F61706578437265';
wwv_flow_api.g_varchar2_table(150) := '6174654D656E75456E74727920657874656E6420656E74727920616374696F6E272C2070456E747279293B0D0A0D0A202020202020696620282070456E7472792E454E5452595F4154545249425554455F3032203D3D202274727565222029207B0D0A20';
wwv_flow_api.g_varchar2_table(151) := '20202020202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F4C4556454C362C20746869732E6C6F675072656669782C20275F617065784372656174654D656E75456E7472792064697361626C6520656E747279206261';
wwv_flow_api.g_varchar2_table(152) := '736564206F6E20656E74727920617474726962757465283229272C2070456E747279293B0D0A2020202020202020656E7472792E64697361626C6564203D20747275653B0D0A2020202020207D0D0A202020207D0D0A0D0A2020202072657475726E2065';
wwv_flow_api.g_varchar2_table(153) := '6E7472793B0D0A20207D2C0D0A20200D0A20205F636F6E766572744F626A6563743A2066756E6374696F6E28297B0D0A20202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F44454255472C20746869732E6C6F675072';
wwv_flow_api.g_varchar2_table(154) := '656669782C20275F636F6E766572744F626A656374272C2027696E272C20242E657874656E64287B7D2C746869732E6F7074696F6E732E6C6973742E656E747269657329293B0D0A0D0A20202020766172206E65774C697374203D205B5D3B0D0A0D0A20';
wwv_flow_api.g_varchar2_table(155) := '202020666F722028766172206920696E20746869732E6F7074696F6E732E6C6973742E656E747269657329207B0D0A2020202020206E65774C6973742E70757368287B0D0A2020202020202020454E5452595F494D414745202020202020202020202020';
wwv_flow_api.g_varchar2_table(156) := '20202020203A20746869732E6F7074696F6E732E6C6973742E656E74726965735B695D2E494D4147452C0D0A2020202020202020454E5452595F544152474554202020202020202020202020202020203A20746869732E6F7074696F6E732E6C6973742E';
wwv_flow_api.g_varchar2_table(157) := '656E74726965735B695D2E5441524745542C0D0A2020202020202020454E5452595F544558542020202020202020202020202020202020203A20746869732E6F7074696F6E732E6C6973742E656E74726965735B695D2E4C4142454C2C0D0A2020202020';
wwv_flow_api.g_varchar2_table(158) := '202020454E5452595F494D4147455F415454524942555445532020202020203A20746869732E6F7074696F6E732E6C6973742E656E74726965735B695D2E494D4147455F4154545249425554452C0D0A2020202020202020454E5452595F494D4147455F';
wwv_flow_api.g_varchar2_table(159) := '414C545F4154545249425554452020203A20746869732E6F7074696F6E732E6C6973742E656E74726965735B695D2E494D4147455F414C545F4154545249425554452C0D0A2020202020202020454E5452595F4154545249425554455F30312020202020';
wwv_flow_api.g_varchar2_table(160) := '20202020203A20746869732E6F7074696F6E732E6C6973742E656E74726965735B695D2E415454524942555445312C0D0A2020202020202020454E5452595F4154545249425554455F3032202020202020202020203A20746869732E6F7074696F6E732E';
wwv_flow_api.g_varchar2_table(161) := '6C6973742E656E74726965735B695D2E415454524942555445322C0D0A2020202020202020454E5452595F4154545249425554455F3033202020202020202020203A20746869732E6F7074696F6E732E6C6973742E656E74726965735B695D2E41545452';
wwv_flow_api.g_varchar2_table(162) := '4942555445332C0D0A2020202020202020454E5452595F4154545249425554455F3034202020202020202020203A20746869732E6F7074696F6E732E6C6973742E656E74726965735B695D2E415454524942555445342C0D0A2020202020202020454E54';
wwv_flow_api.g_varchar2_table(163) := '52595F4154545249425554455F3035202020202020202020203A20746869732E6F7074696F6E732E6C6973742E656E74726965735B695D2E415454524942555445352C0D0A2020202020202020454E5452595F4154545249425554455F30362020202020';
wwv_flow_api.g_varchar2_table(164) := '20202020203A20746869732E6F7074696F6E732E6C6973742E656E74726965735B695D2E415454524942555445362C0D0A2020202020202020454E5452595F4154545249425554455F3037202020202020202020203A20746869732E6F7074696F6E732E';
wwv_flow_api.g_varchar2_table(165) := '6C6973742E656E74726965735B695D2E415454524942555445372C0D0A2020202020202020454E5452595F4154545249425554455F3038202020202020202020203A20746869732E6F7074696F6E732E6C6973742E656E74726965735B695D2E41545452';
wwv_flow_api.g_varchar2_table(166) := '4942555445382C0D0A2020202020202020454E5452595F4154545249425554455F3039202020202020202020203A20746869732E6F7074696F6E732E6C6973742E656E74726965735B695D2E415454524942555445392C0D0A2020202020202020454E54';
wwv_flow_api.g_varchar2_table(167) := '52595F4154545249425554455F3130202020202020202020203A20746869732E6F7074696F6E732E6C6973742E656E74726965735B695D2E41545452494255544531300D0A2020202020207D293B0D0A202020207D0D0A0D0A20202020617065782E6465';
wwv_flow_api.g_varchar2_table(168) := '6275672E6D6573736167652820746869732E435F4C4F475F44454255472C20746869732E6C6F675072656669782C20275F636F6E766572744F626A656374272C20276F7574272C206E65774C697374293B0D0A0D0A2020202072657475726E206E65774C';
wwv_flow_api.g_varchar2_table(169) := '6973743B0D0A20207D2C0D0A20205F7072696E7446756E6374696F6E546F436F6E736F6C653A2066756E6374696F6E28207046756E6374696F6E426F647920297B0D0A20202020766172206172726179203D207046756E6374696F6E426F64792E73706C';
wwv_flow_api.g_varchar2_table(170) := '697428225C6E22293B0D0A20202020666F722028207661722069203D20303B2069203C2061727261792E6C656E6774683B20692B2B2029207B0D0A202020202020617065782E64656275672E6D6573736167652820746869732E435F4C4F475F4C455645';
wwv_flow_api.g_varchar2_table(171) := '4C362C20746869732E6C6F675072656669782C202723272C2061727261795B695D293B0D0A202020207D0D0A20207D2C0D0A2F2F0D0A2F2F0D0A20205F7468726F774572726F723A2066756E6374696F6E2820705465787420297B0D0A20202020617065';
wwv_flow_api.g_varchar2_table(172) := '782E64656275672E6D6573736167652820746869732E435F4C4F475F4C4556454C392C20746869732E6C6F675072656669782C207054657874293B200D0A0D0A20202020617065782E6D6573736167652E636C6561724572726F727328293B0D0A0D0A20';
wwv_flow_api.g_varchar2_table(173) := '202020617065782E6D6573736167652E73686F774572726F727328207B0D0A202020202020747970653A20617065782E6D6573736167652E4552524F522C0D0A2020202020206C6F636174696F6E3A202270616765222C0D0A2020202020206D65737361';
wwv_flow_api.g_varchar2_table(174) := '67653A20273C7374726F6E673E272B746869732E435F504C5547494E5F4E414D452B273C2F7374726F6E673E3A20272B70546578740D0A202020207D20293B0D0A0D0A20202020617065782E64656275672E6D6573736167652820746869732E435F4C4F';
wwv_flow_api.g_varchar2_table(175) := '475F4552524F522C20746869732E6C6F675072656669782C207054657874293B200D0A0D0A20202020746869732E64657374726F7928293B0D0A202020207468726F772070546578743B0D0A20207D2C0D0A202073686F773A2066756E6374696F6E2829';
wwv_flow_api.g_varchar2_table(176) := '7B0D0A202020206966202820746869732E656C656D656E742E676574283029203D3D20646F63756D656E742029207B0D0A202020202020746869732E6D656E75436F6E7461696E65722E6D656E7528226F70656E222C20746869732E6F7074696F6E732E';
wwv_flow_api.g_varchar2_table(177) := '62726F777365724576656E742E70616765582C20746869732E6F7074696F6E732E62726F777365724576656E742E7061676559293B0D0A202020207D0D0A20202020656C7365207B0D0A202020202020746869732E6D656E75436F6E7461696E65722E6D';
wwv_flow_api.g_varchar2_table(178) := '656E7528226F70656E222C20746869732E656C656D656E74293B20200D0A202020207D0D0A202020200D0A20207D2C0D0A20206465626F756E63653A2066756E6374696F6E2866756E632C20776169742C20696D6D65646961746529207B0D0A20202020';
wwv_flow_api.g_varchar2_table(179) := '2F2F617065782E64656275672E6C6F6728276465626F756E6365272C202766756E63272C2066756E632C202777616974272C20776169742C2027696D6D656469617465272C20696D6D656469617465293B0D0A0D0A202020207661722074696D656F7574';
wwv_flow_api.g_varchar2_table(180) := '3B0D0A2020202072657475726E2066756E6374696F6E2829207B0D0A20202020202076617220636F6E74657874203D20746869732C2061726773203D20617267756D656E74733B0D0A202020202020766172206C61746572203D2066756E6374696F6E28';
wwv_flow_api.g_varchar2_table(181) := '29207B0D0A202020202020202074696D656F7574203D206E756C6C3B0D0A20202020202020206966202821696D6D656469617465292066756E632E6170706C7928636F6E746578742C2061726773293B0D0A2020202020207D3B0D0A2020202020207661';
wwv_flow_api.g_varchar2_table(182) := '722063616C6C4E6F77203D20696D6D656469617465202626202174696D656F75743B0D0A202020202020636C65617254696D656F75742874696D656F7574293B0D0A20202020202074696D656F7574203D2073657454696D656F7574286C617465722C20';
wwv_flow_api.g_varchar2_table(183) := '77616974293B0D0A2020202020206966202863616C6C4E6F77292066756E632E6170706C7928636F6E746578742C2061726773293B0D0A202020207D3B0D0A20207D2C0D0A20207468726F74746C653A2066756E6374696F6E2863616C6C6261636B2C20';
wwv_flow_api.g_varchar2_table(184) := '6C696D697429207B0D0A202020207661722077616974203D2066616C73653B2020202020202020202020202020202020202F2F20496E697469616C6C792C207765277265206E6F742077616974696E670D0A2020202072657475726E2066756E6374696F';
wwv_flow_api.g_varchar2_table(185) := '6E202829207B2020202020202020202020202020202F2F2057652072657475726E2061207468726F74746C65642066756E6374696F6E0D0A202020202020202069662028217761697429207B202020202020202020202020202020202020202F2F204966';
wwv_flow_api.g_varchar2_table(186) := '207765277265206E6F742077616974696E670D0A20202020202020202020202063616C6C6261636B2E63616C6C28293B20202020202020202020202F2F20457865637574652075736572732066756E6374696F6E0D0A2020202020202020202020207761';
wwv_flow_api.g_varchar2_table(187) := '6974203D20747275653B2020202020202020202020202020202F2F2050726576656E742066757475726520696E766F636174696F6E730D0A20202020202020202020202073657454696D656F75742866756E6374696F6E202829207B2020202F2F204166';
wwv_flow_api.g_varchar2_table(188) := '746572206120706572696F64206F662074696D650D0A2020202020202020202020202020202077616974203D2066616C73653B202020202020202020202F2F20416E6420616C6C6F772066757475726520696E766F636174696F6E730D0A202020202020';
wwv_flow_api.g_varchar2_table(189) := '2020202020207D2C206C696D6974293B0D0A20202020202020207D0D0A202020207D0D0A20207D0D0A7D293B0D0A0D0A';
null;
end;
/
begin
wwv_flow_api.create_plugin_file(
 p_id=>wwv_flow_api.id(100880806104967349)
,p_plugin_id=>wwv_flow_api.id(80558907627836188)
,p_file_name=>'pretius.apexListMenu.js'
,p_mime_type=>'application/javascript'
,p_file_charset=>'utf-8'
,p_file_content=>wwv_flow_api.varchar2_to_blob(wwv_flow_api.g_varchar2_table)
);
end;
/
begin
wwv_flow_api.import_end(p_auto_install_sup_obj => nvl(wwv_flow_application_install.get_auto_install_sup_obj, false), p_is_component_import => true);
commit;
end;
/
set verify on feedback on define on
prompt  ...done
